from setuptools import setup

setup(name='zs23_menu_fetch',
    version='1.0.1',
    description='Fetches menu in ZS23',
    url='https://github.com/room23studios/zs23_menu_fetch',
    author='Bravo555',
    author_email='mguzik555@gmail.com',
    license='MIT',
    scripts=['bin/menu-fetch'],
	install_requires=['requests'],
    zip_safe=False)
